@@ -52,7 +52,7 @@
 (define-key help-map "C" 'describe-coding-system)
 (define-key help-map "h" 'view-hello-file)
 
-;; Menu for XEmacs were moved to x11/x-menubar.el.
+;; Menu for XEmacs were moved to menubar-items.el.
 
 
 ;; This should be a single character key binding because users use it
@@ -210,7 +210,7 @@ if you want to use your own KEY values, make them start with `user-'."
 	       (setq info (car info)))
 	   (when (featurep 'menubar)
 	     (eval-after-load
-	      "x-menubar.elc"
+	      "menubar-items.elc"
 	      `(add-menu-button
 		'("Mule" "Describe Language Support")
 		(vector ,language-name
@@ -230,7 +230,7 @@ if you want to use your own KEY values, make them start with `user-'."
 	       (setq info (car info)))
 	   (when (featurep 'menubar)
 	     (eval-after-load
-	      "x-menubar.elc"
+	      "menubar-items.elc"
 	      `(add-menu-button
 		'("Mule" "Set Language Environment")
 		(vector ,language-name
